<?php

class tauRates {
    private $cacheLifetime = 21600; // cache lifetime, seconds
    public $installPath; // path to plugin files
    public $url; // plugin folder for URL
    public $cache; // path to source file
    private $readFromCache = false; // read from cache switch
    private $sources = array();
    public $titles = array();
    private $errors = array(); // reading errors
    private $content; // XML data from remote source
    private $settings; // settings to show or not exchange rates
    
    private $rate = array(); // stored exchange rates
    
    public function tauExecute() {
        $this->readXMLSources();
        $this->readSettings();
        
        if(!$this->readFromCache) {
    
            foreach($this->sources as $currency => $link) {
                if(!$xml=simplexml_load_file($link)) $this->errors[$currency] = 1;
                $this->content[$currency] = $xml;
            }
            
            // process exchange rates
            $this->processAZN();
            $this->processKZT();
            $this->processRUB();
            $this->processTJS();
            $this->processTMT();
            $this->processUZS();
            $this->processUAH();
                   
            // update cache
            $this->updateCache();
        }    
        
        // распечатываем результат
        $this->printOutput();
       
    }

    public function setSource($code, $content) {
        $this->sources[$code] = $content;
    }
    
    private function updateCache() {
        $fp = fopen($this->cache,'w+');
        $saveXML = '
        <ratesCache>
            <time>'.time().'</time>
            <Valuta>';
        foreach($this->rate as $name=>$value) {
        $saveXML .='
            <item>
                <name>'.$name.'</name>
                <value>'.$value.'</value>
            </item>';
        }
        $saveXML .= '
            </Valuta>
        </ratesCache>';
        
        fwrite($fp, $saveXML);
        fclose($fp);
    }
    
    private function processAZN() {
        // Azerbiajan Manat AZN
        foreach($this->content['AZN']->ValType->Valute as $num=>$data) {
            $info = $data->attributes();
            if($info['Code']=='USD') $this->rate['AZN'] = str_replace('.',',',$data->Value);
        }
    }
    
    private function processKZT() {
        // Kazakh tenge KZT
        foreach($this->content['KZT']->channel->item as $num=>$data) {
            if($data->title=='USD') $this->rate['KZT'] = str_replace('.',',',$data->description);
        }
    }
    
    private function processRUB() {
        // Russian Ruble (RUB)
        foreach($this->content['RUB']->Valute as $num=>$data) {
            if($data->CharCode=='USD') $this->rate['RUB'] = $data->Value;
        }
    }
    
    private function processTJS() {
        // Tajik Somoni (TJS)
        foreach($this->content['TJS']->Valute as $num=>$data) {
            if($data->CharCode=='USD') $this->rate['TJS'] = $data->Value;
        }
    }
    
    private function processTMT() {
        // Turkmenian Manat TMT
        $source = 'http://bankir.ru/kurs/dollar-ssha-k-novyj-turkmenskij-manat';
        $curl = curl_init($source);
            curl_setopt($curl, CURLOPT_RETURNTRANSFER, true);
            $html = curl_exec($curl);
            curl_close($curl);
        
        $classname = 'result_text_input';
        $dom = new DOMDocument;
        @$dom->loadHTML($html);
        $xpath = new DOMXPath($dom);
        $results = $xpath->query("//*[@class='" . $classname . "']");
        
        if ($results->length > 0) {
            $this->rate['TMT'] = str_replace('.',',',$results->item(0)->nodeValue);
        }
    }
    
    private function processUZS() {
        // Uzbekistan Som UZS
        $source = 'http://www.nbu.com/exchange_rates';
        $curl = curl_init($source);
            curl_setopt($curl, CURLOPT_RETURNTRANSFER, true);
            $html = curl_exec($curl);
            curl_close($curl);
        
        $cut = substr($html, (strpos($html, '<td align="center">USD</td>')-45), 10);
        $cut = preg_replace("/[^0-9\.]/", '', $cut);
        $cut = str_replace('.', ',', $cut);
        
        if ($cut > 0) {
            $this->rate['UZS'] = $cut;
        }
    }
    
    private function processUAH() {
     
        // Ukriane Hryvnia UAH
        $source = 'http://www.bank.gov.ua/control/uk/curmetal/detail/currency?period=daily';
        $curl = curl_init($source);
        curl_setopt($curl, CURLOPT_RETURNTRANSFER, true);
        $html = curl_exec($curl);
        curl_close($curl);
    
        $cut = substr($html, (strpos($html, 'USD')+37), 120);
        preg_match("!<td class=\"cell_c\">(.*?)</td>!si", $cut, $list);
        $dom = new DOMDocument;
        @$dom->loadHTML($list[0]);
        $xpath = new DOMXPath($dom);
        $results = $xpath->query("//*[@class='cell_c']");
        
        $this->rate['UAH'] = str_replace('.',',',(intval($results->item(0)->nodeValue)/100));
          
    }
    
    private function readXMLSources() {
        // Read all XML sources to array
        if(file_exists($this->cache)) {
           $cacheData = simplexml_load_file($this->cache);
           $cacheTime = $cacheData->time;
           if(time() < ($cacheTime+$this->cacheLifetime)) { // проверка устарел ли кэш
                $this->readFromCache = true;
                
                foreach($cacheData->Valuta->item as $data) {
                   $name = strval($data->name[0]);
                   $this->rate[$name] = $data->value;
                }
            }
        } 
    }
    
    private function readSettings() {
        $file = plugin_dir_path( __FILE__ ).'config.xml';
        $settings = array();
	if(file_exists($file) && $xml=simplexml_load_file($file)) {
		
		foreach($xml->Valuta->item as $data) {
		    
		    $code = strval($data->code[0]);
		    $status = strval($data->status[0]);
		    
		    $this->settings[$code] = $status;
		}
	}
    }
    
    private function printOutput() {
        
        echo '<h2 class="widget-title">'.__('Exchange rates to USD','taurates').'</h2>';

        foreach($this->rate as $code=>$value) {
            if($this->settings[$code]) include($this->installPath.'/output_line.tpl');
        }
    }
}


?>