<?php
/*
Plugin Name: TauRates
Text Domain: taurates
Plugin URI: http://mikedudin.com/taurates
Description: Plugin collects data of exchange rates for different currencies to US dollar and displays them.
Version: 1.3
Author: Mikhail Dudin
Author URI: http://mikedudin.com
License: GPL2


    Copyright 2014 Mikhail Dudin (email : mikhail.a.dudin@yandex.ru)
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License, version 2, as 
    published by the Free Software Foundation.
 
    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.
 
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
*/

//error_reporting(0);

require(plugin_dir_path( __FILE__ ).'/tauRatesClass.php');

// Register style sheet.
add_action( 'wp_enqueue_scripts', 'register_taurates_styles' );

// Adding a link to custom CSS file for administration panel
add_action( 'admin_enqueue_scripts', 'taurates_admin_style' );

// Multi-language support
add_action('plugins_loaded', 'taurates_init');

add_action( 'admin_menu', 'taurates_menu' );

function register_taurates_styles() {
	wp_register_style( 'taurates', plugins_url( 'taurates/css/mini.css' ) );
	wp_enqueue_style( 'taurates' );
}

function taurates_init() {
	$plugin_dir = basename(dirname(__FILE__));
	load_plugin_textdomain( 'taurates', false, $plugin_dir );
 
	$GLOBALS['ratesList'] = array('KZT' => __('Kazakhstan Tenge','taurates'),
        'AZN' => __('Azerbaijan Manat','taurates'),
        'RUB' => __('Russian Ruble','taurates'),
        'UAH' => __('Ukraine Hryvnia','taurates'),
        'TJS' => __('Tadjikistan Somoni','taurates'),
        'UZS' => __('Uzbekistan Sum','taurates'),
//        'KGS' => __('Kyrgyzstan Som','taurates'),
//        'BYR' => __('Belorussian Ruble','taurates'),
//        'MDL' => __('Moldovan Leu','taurates'),
//        'AMD' => __('Armenian Dram','taurates'),
        'TMT' => __('Turkmenistan Manat','taurates'));
}

function taurates_menu() {
	add_options_page( 'TauRates Options', 'tauRates', 'manage_options', 'taurates', 'taurates_options' );
}

function taurates_options() {
	if ( !current_user_can( 'manage_options' ) )  {
		wp_die( __( 'You do not have sufficient permissions to access this page.' ) );
	}
	if(isset($_POST['updateSettings'])) taurates_updateSettings();
	taurates_readSettings();
	
	$output = '<h1>'.__('tauRates Options', 'taurates').'</h1>
	<h2>'.__('Display Currencies','taurates').'</h2>
	<form action="'.admin_url().'options-general.php?page=taurates" method="post">
	<input type="hidden" name="updateSettings" value="1" />
	<ul class="optionsList">';
	foreach($GLOBALS['ratesList'] as $code=>$name) {
		if($GLOBALS['tauratesSettings'][$code]==1) $checked = ' checked="checked"';
		else $checked = '';
		$output .= '<li><input type="checkbox" name="show'.$code.'" id="show'.$code.'"'.$checked.' /><label for="show'.$code.'"><img src="'.plugin_dir_url('taurates.php').'taurates/imgs/flag_'.$code.'.png" width="32" />'.$code.' - '.$name.'</label></li>';
	}
	$output .= '</ul>
	<p class="submit"><input type="submit" name="submit" id="submit" class="button button-primary" value="'.__('Save Changes').'"></p></form>';
	echo $output;
}

function taurates_updateSettings() {
	$settings = array();
	foreach($GLOBALS['ratesList'] as $code=>$name) {
		if($_POST['show'.$code]) $show = 1;
		else $show = 0;
		$settings[$code] = $show;
	}
	taurates_saveSettings($settings);
}

function taurates_readSettings() {
	$file = plugin_dir_path( __FILE__ ).'config.xml';
	$settings = array();
	if(file_exists($file) && $xml=simplexml_load_file($file)) {
		
		foreach($xml->Valuta->item as $data) {
		    
		    $code = strval($data->code[0]);
		    $status = strval($data->status[0]);
		    
		    $settings[$code] = $status;
		}
	}
	else {
		foreach($GLOBALS['ratesList'] as $code=>$name) {
			$settings[$code] = 1;
		}
		taurates_saveSettings($settings);
	}
	$GLOBALS['tauratesSettings'] = $settings;
}

function taurates_saveSettings($settings) {
	$fp = fopen(plugin_dir_path( __FILE__ ).'config.xml','w+');
        $saveXML = '
        <tauratesSettings>
            <Valuta>';
        foreach($settings as $name=>$value) {
        $saveXML .='
            <item>
                <code>'.$name.'</code>
                <status>'.$value.'</status>
            </item>';
        }
        $saveXML .= '
            </Valuta>
        </tauratesSettings>';
        
        fwrite($fp, $saveXML);
        fclose($fp);
}

function display_taurates() {
    
    $process = new tauRates();
    $process->installPath = plugin_dir_path( __FILE__ );
    $process->url = plugin_dir_url('taurates.php');
    $process->cache = $process->installPath.'/exRatesCache.xml';
    // Kazakhstan Tenge
    $process->setSource('KZT', 'http://www.nationalbank.kz/rss/rates_all.xml');
    
    // Azerbaijan Manat
    $process->setSource('AZN', 'http://cbar.az/currencies/'.date('d.m.Y').'.xml');
    
    // Russian Ruble
    $process->setSource('RUB', 'http://cbr.ru/scripts/XML_daily.asp');
    
    // Tajikistan Somoni
    $process->setSource('TJS', 'http://www.nbt.tj/ru/kurs/?c=4&id=28&lg=ru&d='.date('d-m-Y').'&export=xmlout');
    
    $process->titles = $GLOBALS['ratesList'];
    
    $process->tauExecute();
}

function taurates_admin_style() {
	wp_register_style( 'tauratesAdmin', plugins_url( 'taurates/css/tauratesAdmin.css' ) );
	wp_enqueue_style( 'tauratesAdmin' );
}

?>